==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/coremotion/CMStepCounter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coremotion;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 7.0 and later.
 * @deprecated Deprecated in iOS 8.0.
 */
@Deprecated
/*</javadoc>*/
/*<annotations>*/@Library("CoreMotion") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CMStepCounter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class CMStepCounterPtr extends Ptr<CMStepCounter, CMStepCounterPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(CMStepCounter.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public CMStepCounter() {}
    protected CMStepCounter(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "queryStepCountStartingFrom:to:toQueue:withHandler:")
    public native void queryStepCount(NSDate start, NSDate end, NSOperationQueue queue, @Block("(@MachineSizedSInt,)") VoidBlock2<Long, NSError> handler);
    @Method(selector = "startStepCountingUpdatesToQueue:updateOn:withHandler:")
    public native void startStepCountingUpdates(NSOperationQueue queue, @MachineSizedSInt long stepCounts, @Block("(@MachineSizedSInt,,)") VoidBlock3<Long, NSDate, NSError> handler);
    @Method(selector = "stopStepCountingUpdates")
    public native void stopStepCountingUpdates();
    @Method(selector = "isStepCountingAvailable")
    public static native boolean isStepCountingAvailable();
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/coremotion/CMStepCounter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coremotion;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @deprecated Deprecated in iOS 8.0. Use CMPedometer instead
 */
/*</javadoc>*/
/*<annotations>*/@Library("CoreMotion") @NativeClass @Deprecated/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CMStepCounter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class CMStepCounterPtr extends Ptr<CMStepCounter, CMStepCounterPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(CMStepCounter.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public CMStepCounter() {}
    protected CMStepCounter(Handle h, long handle) { super(h, handle); }
    protected CMStepCounter(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "queryStepCountStartingFrom:to:toQueue:withHandler:")
    public native void queryStepCount(NSDate start, NSDate end, NSOperationQueue queue, @Block("(@MachineSizedSInt,)") VoidBlock2<Long, NSError> handler);
    @Method(selector = "startStepCountingUpdatesToQueue:updateOn:withHandler:")
    public native void startStepCountingUpdates(NSOperationQueue queue, @MachineSizedSInt long stepCounts, @Block("(@MachineSizedSInt,,)") VoidBlock3<Long, NSDate, NSError> handler);
    @Method(selector = "stopStepCountingUpdates")
    public native void stopStepCountingUpdates();
    @Method(selector = "isStepCountingAvailable")
    public static native boolean isStepCountingAvailable();
    /*</methods>*/
}
